@@ -1,9 +1,12 @@
+from typing import Any
+
 from django import forms
 from edc_constants.constants import NEVER, OTHER, YES
 
 
 class MedicationAdherenceFormValidatorMixin:
-    def clean(self):
+    def _clean(self: Any):
+        super()._clean()  # noqa
         self.confirm_visual_scores_match()
         self.required_if(
             YES,
@@ -14,7 +17,7 @@ class MedicationAdherenceFormValidatorMixin:
         self.require_m2m_if_missed_any_pills()
         self.missed_pill_reason_other_specify()
 
-    def confirm_visual_scores_match(self):
+    def confirm_visual_scores_match(self: Any):
         confirmed = self.cleaned_data.get("visual_score_confirmed")
         if confirmed is not None:
             if int(self.cleaned_data.get("visual_score_slider", "0")) != confirmed:
@@ -22,14 +25,14 @@ class MedicationAdherenceFormValidatorMixin:
                     {"visual_score_confirmed": "Does not match visual score above."}
                 )
 
-    def require_m2m_if_missed_any_pills(self):
+    def require_m2m_if_missed_any_pills(self: Any):
         if self.cleaned_data.get("last_missed_pill"):
             if self.cleaned_data.get("last_missed_pill") == NEVER:
                 self.m2m_not_required("missed_pill_reason")
             else:
                 self.m2m_required("missed_pill_reason")
 
-    def missed_pill_reason_other_specify(self):
+    def missed_pill_reason_other_specify(self: Any):
         self.m2m_other_specify(
             OTHER,
             m2m_field="missed_pill_reason",
